==> formant-1.230.2-py2.py3-none-any.whl: formant/sdk/cloud/v2/formant_admin_api_client/models/event_histogram.py <==
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar

import attr

if TYPE_CHECKING:
    from ..models.event_histogram_entry import EventHistogramEntry


T = TypeVar("T", bound="EventHistogram")


@attr.s(auto_attribs=True)
class EventHistogram:
    """
    Attributes:
        counts (List['EventHistogramEntry']):
    """

    counts: List["EventHistogramEntry"]
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        counts = []
        for counts_item_data in self.counts:
            counts_item = counts_item_data.to_dict()

            counts.append(counts_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "counts": counts,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.event_histogram_entry import EventHistogramEntry

        d = src_dict.copy()
        counts = []
        _counts = d.pop("counts")
        for counts_item_data in _counts:
            counts_item = EventHistogramEntry.from_dict(counts_item_data)

            counts.append(counts_item)

        event_histogram = cls(
            counts=counts,
        )

        event_histogram.additional_properties = d
        return event_histogram

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> formant-1.268.2-py2.py3-none-any.whl: formant/sdk/cloud/v2/formant_admin_api_client/models/event_histogram.py <==
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar

import attr

if TYPE_CHECKING:
  from ..models.event_histogram_entry import EventHistogramEntry




T = TypeVar("T", bound="EventHistogram")

@attr.s(auto_attribs=True)
class EventHistogram:
    """
    Attributes:
        counts (List['EventHistogramEntry']):
    """

    counts: List['EventHistogramEntry']
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)


    def to_dict(self) -> Dict[str, Any]:
        counts = []
        for counts_item_data in self.counts:
            counts_item = counts_item_data.to_dict()

            counts.append(counts_item)





        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "counts": counts,
        })

        return field_dict



    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.event_histogram_entry import EventHistogramEntry
        d = src_dict.copy()
        counts = []
        _counts = d.pop("counts")
        for counts_item_data in (_counts):
            counts_item = EventHistogramEntry.from_dict(counts_item_data)



            counts.append(counts_item)


        event_histogram = cls(
            counts=counts,
        )

        event_histogram.additional_properties = d
        return event_histogram

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
